==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QCloseEvent_shell.cpp <==
#include "QCloseEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QCloseEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCloseEvent")
    QCloseEvent *_ptr = reinterpret_cast<QCloseEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QCloseEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QCloseEvent_shell) ); }

jmethodID QCloseEvent_shell::__shell_javaMethod(int pos) const { return QCloseEvent_shell::__shell()->javaMethod(typeid(QCloseEvent), pos); }

// emitting (writeShellConstructor)
QCloseEvent_shell::QCloseEvent_shell()
    : QCloseEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QCloseEvent::QCloseEvent_shell()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->constructed(typeid(QCloseEvent));
}

// emitting (writeShellDestructor)
QCloseEvent_shell::~QCloseEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QCloseEvent::~QCloseEvent()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->destructed(typeid(QCloseEvent));
}

void QCloseEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QCloseEvent_shell*>(ptr)->QCloseEvent_shell::__shell()->tryDeleteShell(typeid(QCloseEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QCloseEvent()
void __qt_construct_QCloseEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCloseEvent()")
    Q_UNUSED(__java_arguments)
    QCloseEvent *__qt_this = new(__qtjambi_ptr) QCloseEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCloseEvent_shell
void __qt_destruct_QCloseEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCloseEvent")
    reinterpret_cast<QCloseEvent_shell*>(ptr)->~QCloseEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCloseEvent::QCloseEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_initialize_1native__Lio_qt_gui_QCloseEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCloseEvent::QCloseEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCloseEvent_0, sizeof(QCloseEvent_shell), typeid(QCloseEvent), true, &deleter_QCloseEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCloseEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCloseEvent>("QCloseEvent", "io/qt/gui/QCloseEvent");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCloseEvent, {
        ConstructorInfo(&__qt_construct_QCloseEvent_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCloseEvent);
    registerMetaType<QCloseEvent>("QCloseEvent");
    registerSizeOfShell(typeId, sizeof(QCloseEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QCloseEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QCloseEvent_shell.cpp <==
#include "QCloseEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QCloseEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCloseEvent")
    QCloseEvent *_ptr = reinterpret_cast<QCloseEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QCloseEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QCloseEvent_shell) ); }

jmethodID QCloseEvent_shell::__shell_javaMethod(int pos) const { return QCloseEvent_shell::__shell()->javaMethod(typeid(QCloseEvent), pos); }

// emitting (writeShellConstructor)
QCloseEvent_shell::QCloseEvent_shell()
    : QCloseEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QCloseEvent::QCloseEvent_shell()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->constructed(typeid(QCloseEvent));
}

QCloseEvent_shell::QCloseEvent_shell(const QCloseEvent& other0)
    : QCloseEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QCloseEvent::QCloseEvent_shell(const QCloseEvent& other0)", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->constructed(typeid(QCloseEvent));
}

// emitting (writeShellDestructor)
QCloseEvent_shell::~QCloseEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QCloseEvent::~QCloseEvent()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->destructed(typeid(QCloseEvent));
}

void QCloseEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QCloseEvent_shell*>(ptr)->QCloseEvent_shell::__shell()->tryDeleteShell(typeid(QCloseEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QCloseEvent()
void __qt_construct_QCloseEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCloseEvent()")
    Q_UNUSED(__java_arguments)
    QCloseEvent *__qt_this = new(__qtjambi_ptr) QCloseEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QCloseEvent::QCloseEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_initialize_1native__Lio_qt_gui_QCloseEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCloseEvent::QCloseEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCloseEvent, sizeof(QCloseEvent_shell), typeid(QCloseEvent), true, &deleter_QCloseEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCloseEvent(QCloseEvent)
void __qt_construct_QCloseEvent_cref_QCloseEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCloseEvent(QCloseEvent)")
    jobject other0 = __java_arguments[0].l;
    const QCloseEvent& __qt_other0 = qtjambi_cast<const QCloseEvent& >(__jni_env, other0);
    QCloseEvent *__qt_this = new(__qtjambi_ptr) QCloseEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QCloseEvent::QCloseEvent(QCloseEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_initialize_1native__Lio_qt_gui_QCloseEvent_2Lio_qt_gui_QCloseEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCloseEvent::QCloseEvent(QCloseEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCloseEvent_cref_QCloseEvent, sizeof(QCloseEvent_shell), typeid(QCloseEvent), true, &deleter_QCloseEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCloseEvent_shell
void __qt_destruct_QCloseEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCloseEvent")
    reinterpret_cast<QCloseEvent_shell*>(ptr)->~QCloseEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCloseEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCloseEvent>("QCloseEvent", "io/qt/gui/QCloseEvent");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCloseEvent, {
        ConstructorInfo(&__qt_construct_QCloseEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QCloseEvent_cref_QCloseEvent, "Lio/qt/gui/QCloseEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCloseEvent);
    registerMetaType<QCloseEvent>("QCloseEvent");
    registerSizeOfShell(typeId, sizeof(QCloseEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QCloseEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
